# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class SetPassPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'expire_password': 'bool',
        'expire_password_after': 'int',
        'password_history': 'int',
        'min_password_length': 'int',
        'password_must_contain_letters': 'bool',
        'password_must_contain_numbers': 'bool',
        'password_must_contain_uppercase_letters': 'bool',
        'password_must_contain_special_characters': 'bool'
    }

    attribute_map = {
        'expire_password': 'expire_password',
        'expire_password_after': 'expire_password_after',
        'password_history': 'password_history',
        'min_password_length': 'min_password_length',
        'password_must_contain_letters': 'password_must_contain_letters',
        'password_must_contain_numbers': 'password_must_contain_numbers',
        'password_must_contain_uppercase_letters': 'password_must_contain_uppercase_letters',
        'password_must_contain_special_characters': 'password_must_contain_special_characters'
    }

    def __init__(self, expire_password=False, expire_password_after=None, password_history=None, min_password_length=None, password_must_contain_letters=True, password_must_contain_numbers=True, password_must_contain_uppercase_letters=False, password_must_contain_special_characters=False, _configuration=None):  # noqa: E501
        """SetPassPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._expire_password = None
        self._expire_password_after = None
        self._password_history = None
        self._min_password_length = None
        self._password_must_contain_letters = None
        self._password_must_contain_numbers = None
        self._password_must_contain_uppercase_letters = None
        self._password_must_contain_special_characters = None
        self.discriminator = None

        if expire_password is not None:
            self.expire_password = expire_password
        if expire_password_after is not None:
            self.expire_password_after = expire_password_after
        if password_history is not None:
            self.password_history = password_history
        if min_password_length is not None:
            self.min_password_length = min_password_length
        if password_must_contain_letters is not None:
            self.password_must_contain_letters = password_must_contain_letters
        if password_must_contain_numbers is not None:
            self.password_must_contain_numbers = password_must_contain_numbers
        if password_must_contain_uppercase_letters is not None:
            self.password_must_contain_uppercase_letters = password_must_contain_uppercase_letters
        if password_must_contain_special_characters is not None:
            self.password_must_contain_special_characters = password_must_contain_special_characters

    @property
    def expire_password(self):
        """Gets the expire_password of this SetPassPolicy.  # noqa: E501

        Enforce password expiration  # noqa: E501

        :return: The expire_password of this SetPassPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._expire_password

    @expire_password.setter
    def expire_password(self, expire_password):
        """Sets the expire_password of this SetPassPolicy.

        Enforce password expiration  # noqa: E501

        :param expire_password: The expire_password of this SetPassPolicy.  # noqa: E501
        :type: bool
        """

        self._expire_password = expire_password

    @property
    def expire_password_after(self):
        """Gets the expire_password_after of this SetPassPolicy.  # noqa: E501

        Expire passwords after (seconds), between 1296000 to 432000000 seconds (15 to 5000 days)  # noqa: E501

        :return: The expire_password_after of this SetPassPolicy.  # noqa: E501
        :rtype: int
        """
        return self._expire_password_after

    @expire_password_after.setter
    def expire_password_after(self, expire_password_after):
        """Sets the expire_password_after of this SetPassPolicy.

        Expire passwords after (seconds), between 1296000 to 432000000 seconds (15 to 5000 days)  # noqa: E501

        :param expire_password_after: The expire_password_after of this SetPassPolicy.  # noqa: E501
        :type: int
        """

        self._expire_password_after = expire_password_after

    @property
    def password_history(self):
        """Gets the password_history of this SetPassPolicy.  # noqa: E501

        Number of passwords to remember, between 1 to 10  # noqa: E501

        :return: The password_history of this SetPassPolicy.  # noqa: E501
        :rtype: int
        """
        return self._password_history

    @password_history.setter
    def password_history(self, password_history):
        """Sets the password_history of this SetPassPolicy.

        Number of passwords to remember, between 1 to 10  # noqa: E501

        :param password_history: The password_history of this SetPassPolicy.  # noqa: E501
        :type: int
        """

        self._password_history = password_history

    @property
    def min_password_length(self):
        """Gets the min_password_length of this SetPassPolicy.  # noqa: E501

        Min password length, between 8 to 12  # noqa: E501

        :return: The min_password_length of this SetPassPolicy.  # noqa: E501
        :rtype: int
        """
        return self._min_password_length

    @min_password_length.setter
    def min_password_length(self, min_password_length):
        """Sets the min_password_length of this SetPassPolicy.

        Min password length, between 8 to 12  # noqa: E501

        :param min_password_length: The min_password_length of this SetPassPolicy.  # noqa: E501
        :type: int
        """

        self._min_password_length = min_password_length

    @property
    def password_must_contain_letters(self):
        """Gets the password_must_contain_letters of this SetPassPolicy.  # noqa: E501

        Password must contain letters  # noqa: E501

        :return: The password_must_contain_letters of this SetPassPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._password_must_contain_letters

    @password_must_contain_letters.setter
    def password_must_contain_letters(self, password_must_contain_letters):
        """Sets the password_must_contain_letters of this SetPassPolicy.

        Password must contain letters  # noqa: E501

        :param password_must_contain_letters: The password_must_contain_letters of this SetPassPolicy.  # noqa: E501
        :type: bool
        """

        self._password_must_contain_letters = password_must_contain_letters

    @property
    def password_must_contain_numbers(self):
        """Gets the password_must_contain_numbers of this SetPassPolicy.  # noqa: E501

        Password must contain numbers  # noqa: E501

        :return: The password_must_contain_numbers of this SetPassPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._password_must_contain_numbers

    @password_must_contain_numbers.setter
    def password_must_contain_numbers(self, password_must_contain_numbers):
        """Sets the password_must_contain_numbers of this SetPassPolicy.

        Password must contain numbers  # noqa: E501

        :param password_must_contain_numbers: The password_must_contain_numbers of this SetPassPolicy.  # noqa: E501
        :type: bool
        """

        self._password_must_contain_numbers = password_must_contain_numbers

    @property
    def password_must_contain_uppercase_letters(self):
        """Gets the password_must_contain_uppercase_letters of this SetPassPolicy.  # noqa: E501

        Password must contain uppercase letters  # noqa: E501

        :return: The password_must_contain_uppercase_letters of this SetPassPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._password_must_contain_uppercase_letters

    @password_must_contain_uppercase_letters.setter
    def password_must_contain_uppercase_letters(self, password_must_contain_uppercase_letters):
        """Sets the password_must_contain_uppercase_letters of this SetPassPolicy.

        Password must contain uppercase letters  # noqa: E501

        :param password_must_contain_uppercase_letters: The password_must_contain_uppercase_letters of this SetPassPolicy.  # noqa: E501
        :type: bool
        """

        self._password_must_contain_uppercase_letters = password_must_contain_uppercase_letters

    @property
    def password_must_contain_special_characters(self):
        """Gets the password_must_contain_special_characters of this SetPassPolicy.  # noqa: E501

        Password must contain special characters  # noqa: E501

        :return: The password_must_contain_special_characters of this SetPassPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._password_must_contain_special_characters

    @password_must_contain_special_characters.setter
    def password_must_contain_special_characters(self, password_must_contain_special_characters):
        """Sets the password_must_contain_special_characters of this SetPassPolicy.

        Password must contain special characters  # noqa: E501

        :param password_must_contain_special_characters: The password_must_contain_special_characters of this SetPassPolicy.  # noqa: E501
        :type: bool
        """

        self._password_must_contain_special_characters = password_must_contain_special_characters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetPassPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetPassPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SetPassPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20025Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation_zones': 'list[str]',
        'cache': 'InlineResponse20025Cache',
        'app_engine': 'InlineResponse20025AppEngine',
        'status': 'str',
        'description': 'str',
        'fibre_channel': 'bool',
        'drives': 'InlineResponse20025Drives',
        'drive_count': 'int',
        'engine': 'InlineResponse20025Engine',
        'nova_id': 'int',
        'management_url': 'str',
        'initial_passcode': 'str',
        'ip_address': 'str',
        'id': 'int',
        'time_created_gmt': 'str',
        'name': 'str',
        'locked_down': 'int',
        'provider': 'InlineResponse20025Provider',
        'product': 'str',
        'type': 'str',
        'virtual_network_interfaces': 'list[str]',
        'flc_enabled': 'bool',
        'iscsi_dual_target_mode_enabled': 'bool'
    }

    attribute_map = {
        'allocation_zones': 'allocation-zones',
        'cache': 'cache',
        'app_engine': 'app_engine',
        'status': 'status',
        'description': 'description',
        'fibre_channel': 'fibre_channel',
        'drives': 'drives',
        'drive_count': 'drive_count',
        'engine': 'engine',
        'nova_id': 'nova_id',
        'management_url': 'management_url',
        'initial_passcode': 'initial_passcode',
        'ip_address': 'ip_address',
        'id': 'id',
        'time_created_gmt': 'time_created_gmt',
        'name': 'name',
        'locked_down': 'locked_down',
        'provider': 'provider',
        'product': 'product',
        'type': 'type',
        'virtual_network_interfaces': 'virtual_network_interfaces',
        'flc_enabled': 'flc_enabled',
        'iscsi_dual_target_mode_enabled': 'iscsi_dual_target_mode_enabled'
    }

    def __init__(self, allocation_zones=None, cache=None, app_engine=None, status=None, description=None, fibre_channel=None, drives=None, drive_count=None, engine=None, nova_id=None, management_url=None, initial_passcode=None, ip_address=None, id=None, time_created_gmt=None, name=None, locked_down=None, provider=None, product=None, type=None, virtual_network_interfaces=None, flc_enabled=None, iscsi_dual_target_mode_enabled=None, _configuration=None):  # noqa: E501
        """InlineResponse20025Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allocation_zones = None
        self._cache = None
        self._app_engine = None
        self._status = None
        self._description = None
        self._fibre_channel = None
        self._drives = None
        self._drive_count = None
        self._engine = None
        self._nova_id = None
        self._management_url = None
        self._initial_passcode = None
        self._ip_address = None
        self._id = None
        self._time_created_gmt = None
        self._name = None
        self._locked_down = None
        self._provider = None
        self._product = None
        self._type = None
        self._virtual_network_interfaces = None
        self._flc_enabled = None
        self._iscsi_dual_target_mode_enabled = None
        self.discriminator = None

        if allocation_zones is not None:
            self.allocation_zones = allocation_zones
        if cache is not None:
            self.cache = cache
        if app_engine is not None:
            self.app_engine = app_engine
        if status is not None:
            self.status = status
        if description is not None:
            self.description = description
        if fibre_channel is not None:
            self.fibre_channel = fibre_channel
        if drives is not None:
            self.drives = drives
        if drive_count is not None:
            self.drive_count = drive_count
        if engine is not None:
            self.engine = engine
        if nova_id is not None:
            self.nova_id = nova_id
        if management_url is not None:
            self.management_url = management_url
        if initial_passcode is not None:
            self.initial_passcode = initial_passcode
        if ip_address is not None:
            self.ip_address = ip_address
        if id is not None:
            self.id = id
        if time_created_gmt is not None:
            self.time_created_gmt = time_created_gmt
        if name is not None:
            self.name = name
        if locked_down is not None:
            self.locked_down = locked_down
        if provider is not None:
            self.provider = provider
        if product is not None:
            self.product = product
        if type is not None:
            self.type = type
        if virtual_network_interfaces is not None:
            self.virtual_network_interfaces = virtual_network_interfaces
        if flc_enabled is not None:
            self.flc_enabled = flc_enabled
        if iscsi_dual_target_mode_enabled is not None:
            self.iscsi_dual_target_mode_enabled = iscsi_dual_target_mode_enabled

    @property
    def allocation_zones(self):
        """Gets the allocation_zones of this InlineResponse20025Data.  # noqa: E501


        :return: The allocation_zones of this InlineResponse20025Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_zones

    @allocation_zones.setter
    def allocation_zones(self, allocation_zones):
        """Sets the allocation_zones of this InlineResponse20025Data.


        :param allocation_zones: The allocation_zones of this InlineResponse20025Data.  # noqa: E501
        :type: list[str]
        """

        self._allocation_zones = allocation_zones

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20025Data.  # noqa: E501


        :return: The cache of this InlineResponse20025Data.  # noqa: E501
        :rtype: InlineResponse20025Cache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20025Data.


        :param cache: The cache of this InlineResponse20025Data.  # noqa: E501
        :type: InlineResponse20025Cache
        """

        self._cache = cache

    @property
    def app_engine(self):
        """Gets the app_engine of this InlineResponse20025Data.  # noqa: E501


        :return: The app_engine of this InlineResponse20025Data.  # noqa: E501
        :rtype: InlineResponse20025AppEngine
        """
        return self._app_engine

    @app_engine.setter
    def app_engine(self, app_engine):
        """Sets the app_engine of this InlineResponse20025Data.


        :param app_engine: The app_engine of this InlineResponse20025Data.  # noqa: E501
        :type: InlineResponse20025AppEngine
        """

        self._app_engine = app_engine

    @property
    def status(self):
        """Gets the status of this InlineResponse20025Data.  # noqa: E501


        :return: The status of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20025Data.


        :param status: The status of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def description(self):
        """Gets the description of this InlineResponse20025Data.  # noqa: E501


        :return: The description of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse20025Data.


        :param description: The description of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def fibre_channel(self):
        """Gets the fibre_channel of this InlineResponse20025Data.  # noqa: E501


        :return: The fibre_channel of this InlineResponse20025Data.  # noqa: E501
        :rtype: bool
        """
        return self._fibre_channel

    @fibre_channel.setter
    def fibre_channel(self, fibre_channel):
        """Sets the fibre_channel of this InlineResponse20025Data.


        :param fibre_channel: The fibre_channel of this InlineResponse20025Data.  # noqa: E501
        :type: bool
        """

        self._fibre_channel = fibre_channel

    @property
    def drives(self):
        """Gets the drives of this InlineResponse20025Data.  # noqa: E501


        :return: The drives of this InlineResponse20025Data.  # noqa: E501
        :rtype: InlineResponse20025Drives
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this InlineResponse20025Data.


        :param drives: The drives of this InlineResponse20025Data.  # noqa: E501
        :type: InlineResponse20025Drives
        """

        self._drives = drives

    @property
    def drive_count(self):
        """Gets the drive_count of this InlineResponse20025Data.  # noqa: E501


        :return: The drive_count of this InlineResponse20025Data.  # noqa: E501
        :rtype: int
        """
        return self._drive_count

    @drive_count.setter
    def drive_count(self, drive_count):
        """Sets the drive_count of this InlineResponse20025Data.


        :param drive_count: The drive_count of this InlineResponse20025Data.  # noqa: E501
        :type: int
        """

        self._drive_count = drive_count

    @property
    def engine(self):
        """Gets the engine of this InlineResponse20025Data.  # noqa: E501


        :return: The engine of this InlineResponse20025Data.  # noqa: E501
        :rtype: InlineResponse20025Engine
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this InlineResponse20025Data.


        :param engine: The engine of this InlineResponse20025Data.  # noqa: E501
        :type: InlineResponse20025Engine
        """

        self._engine = engine

    @property
    def nova_id(self):
        """Gets the nova_id of this InlineResponse20025Data.  # noqa: E501


        :return: The nova_id of this InlineResponse20025Data.  # noqa: E501
        :rtype: int
        """
        return self._nova_id

    @nova_id.setter
    def nova_id(self, nova_id):
        """Sets the nova_id of this InlineResponse20025Data.


        :param nova_id: The nova_id of this InlineResponse20025Data.  # noqa: E501
        :type: int
        """

        self._nova_id = nova_id

    @property
    def management_url(self):
        """Gets the management_url of this InlineResponse20025Data.  # noqa: E501


        :return: The management_url of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this InlineResponse20025Data.


        :param management_url: The management_url of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def initial_passcode(self):
        """Gets the initial_passcode of this InlineResponse20025Data.  # noqa: E501


        :return: The initial_passcode of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._initial_passcode

    @initial_passcode.setter
    def initial_passcode(self, initial_passcode):
        """Sets the initial_passcode of this InlineResponse20025Data.


        :param initial_passcode: The initial_passcode of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._initial_passcode = initial_passcode

    @property
    def ip_address(self):
        """Gets the ip_address of this InlineResponse20025Data.  # noqa: E501


        :return: The ip_address of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this InlineResponse20025Data.


        :param ip_address: The ip_address of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def id(self):
        """Gets the id of this InlineResponse20025Data.  # noqa: E501


        :return: The id of this InlineResponse20025Data.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20025Data.


        :param id: The id of this InlineResponse20025Data.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def time_created_gmt(self):
        """Gets the time_created_gmt of this InlineResponse20025Data.  # noqa: E501


        :return: The time_created_gmt of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._time_created_gmt

    @time_created_gmt.setter
    def time_created_gmt(self, time_created_gmt):
        """Sets the time_created_gmt of this InlineResponse20025Data.


        :param time_created_gmt: The time_created_gmt of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._time_created_gmt = time_created_gmt

    @property
    def name(self):
        """Gets the name of this InlineResponse20025Data.  # noqa: E501


        :return: The name of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20025Data.


        :param name: The name of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def locked_down(self):
        """Gets the locked_down of this InlineResponse20025Data.  # noqa: E501


        :return: The locked_down of this InlineResponse20025Data.  # noqa: E501
        :rtype: int
        """
        return self._locked_down

    @locked_down.setter
    def locked_down(self, locked_down):
        """Sets the locked_down of this InlineResponse20025Data.


        :param locked_down: The locked_down of this InlineResponse20025Data.  # noqa: E501
        :type: int
        """

        self._locked_down = locked_down

    @property
    def provider(self):
        """Gets the provider of this InlineResponse20025Data.  # noqa: E501


        :return: The provider of this InlineResponse20025Data.  # noqa: E501
        :rtype: InlineResponse20025Provider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this InlineResponse20025Data.


        :param provider: The provider of this InlineResponse20025Data.  # noqa: E501
        :type: InlineResponse20025Provider
        """

        self._provider = provider

    @property
    def product(self):
        """Gets the product of this InlineResponse20025Data.  # noqa: E501


        :return: The product of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this InlineResponse20025Data.


        :param product: The product of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def type(self):
        """Gets the type of this InlineResponse20025Data.  # noqa: E501


        :return: The type of this InlineResponse20025Data.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InlineResponse20025Data.


        :param type: The type of this InlineResponse20025Data.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def virtual_network_interfaces(self):
        """Gets the virtual_network_interfaces of this InlineResponse20025Data.  # noqa: E501


        :return: The virtual_network_interfaces of this InlineResponse20025Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._virtual_network_interfaces

    @virtual_network_interfaces.setter
    def virtual_network_interfaces(self, virtual_network_interfaces):
        """Sets the virtual_network_interfaces of this InlineResponse20025Data.


        :param virtual_network_interfaces: The virtual_network_interfaces of this InlineResponse20025Data.  # noqa: E501
        :type: list[str]
        """

        self._virtual_network_interfaces = virtual_network_interfaces

    @property
    def flc_enabled(self):
        """Gets the flc_enabled of this InlineResponse20025Data.  # noqa: E501


        :return: The flc_enabled of this InlineResponse20025Data.  # noqa: E501
        :rtype: bool
        """
        return self._flc_enabled

    @flc_enabled.setter
    def flc_enabled(self, flc_enabled):
        """Sets the flc_enabled of this InlineResponse20025Data.


        :param flc_enabled: The flc_enabled of this InlineResponse20025Data.  # noqa: E501
        :type: bool
        """

        self._flc_enabled = flc_enabled

    @property
    def iscsi_dual_target_mode_enabled(self):
        """Gets the iscsi_dual_target_mode_enabled of this InlineResponse20025Data.  # noqa: E501


        :return: The iscsi_dual_target_mode_enabled of this InlineResponse20025Data.  # noqa: E501
        :rtype: bool
        """
        return self._iscsi_dual_target_mode_enabled

    @iscsi_dual_target_mode_enabled.setter
    def iscsi_dual_target_mode_enabled(self, iscsi_dual_target_mode_enabled):
        """Sets the iscsi_dual_target_mode_enabled of this InlineResponse20025Data.


        :param iscsi_dual_target_mode_enabled: The iscsi_dual_target_mode_enabled of this InlineResponse20025Data.  # noqa: E501
        :type: bool
        """

        self._iscsi_dual_target_mode_enabled = iscsi_dual_target_mode_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20025Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20025Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20025Data):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.settings_api import SettingsApi  # noqa: E501
from Vpsa.rest import ApiException


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.settings_api.SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_encryption_to_aws_kms(self):
        """Test case for change_encryption_to_aws_kms

        """
        pass

    def test_change_mtu_for_ni(self):
        """Test case for change_mtu_for_ni

        """
        pass

    def test_configure_file_access_audit(self):
        """Test case for configure_file_access_audit

        """
        pass

    def test_create_zcs_image_repository(self):
        """Test case for create_zcs_image_repository

        """
        pass

    def test_default_write_policy(self):
        """Test case for default_write_policy

        """
        pass

    def test_delete_zcs_image_repository(self):
        """Test case for delete_zcs_image_repository

        """
        pass

    def test_disable_defrag(self):
        """Test case for disable_defrag

        """
        pass

    def test_disable_file_access_audit_conf(self):
        """Test case for disable_file_access_audit_conf

        """
        pass

    def test_disable_privilege_access(self):
        """Test case for disable_privilege_access

        """
        pass

    def test_disable_trim(self):
        """Test case for disable_trim

        """
        pass

    def test_download_metering_database(self):
        """Test case for download_metering_database

        """
        pass

    def test_enable_defrag(self):
        """Test case for enable_defrag

        """
        pass

    def test_enable_privilege_access(self):
        """Test case for enable_privilege_access

        """
        pass

    def test_enable_trim(self):
        """Test case for enable_trim

        """
        pass

    def test_get_all_app_settings(self):
        """Test case for get_all_app_settings

        """
        pass

    def test_get_network(self):
        """Test case for get_network

        """
        pass

    def test_get_nfs_domain(self):
        """Test case for get_nfs_domain

        """
        pass

    def test_get_public_ip(self):
        """Test case for get_public_ip

        """
        pass

    def test_get_vpsa_flc_global(self):
        """Test case for get_vpsa_flc_global

        """
        pass

    def test_get_zcs_settings(self):
        """Test case for get_zcs_settings

        """
        pass

    def test_list_all_vc_capabilities(self):
        """Test case for list_all_vc_capabilities

        """
        pass

    def test_migrate_zcs_image_repository(self):
        """Test case for migrate_zcs_image_repository

        """
        pass

    def test_remove_encryption_kms(self):
        """Test case for remove_encryption_kms

        """
        pass

    def test_remove_encryption_password(self):
        """Test case for remove_encryption_password

        """
        pass

    def test_restore_aws_kms_store(self):
        """Test case for restore_aws_kms_store

        """
        pass

    def test_restore_encryption_password(self):
        """Test case for restore_encryption_password

        """
        pass

    def test_restore_encryption_password_kmip(self):
        """Test case for restore_encryption_password_kmip

        """
        pass

    def test_set_encription_pass(self):
        """Test case for set_encription_pass

        """
        pass

    def test_set_encription_pass_or_use_aws_kms_store(self):
        """Test case for set_encription_pass_or_use_aws_kms_store

        """
        pass

    def test_set_encryption_password_kmip(self):
        """Test case for set_encryption_password_kmip

        """
        pass

    def test_set_global_server_connectivity_monitoring(self):
        """Test case for set_global_server_connectivity_monitoring

        """
        pass

    def test_set_iscsi_over_public_ip(self):
        """Test case for set_iscsi_over_public_ip

        """
        pass

    def test_set_multizone_read_mode(self):
        """Test case for set_multizone_read_mode

        """
        pass

    def test_set_nfs_domain(self):
        """Test case for set_nfs_domain

        """
        pass

    def test_set_pass_policy(self):
        """Test case for set_pass_policy

        """
        pass

    def test_set_recycle_bin(self):
        """Test case for set_recycle_bin

        """
        pass

    def test_set_smb_charset(self):
        """Test case for set_smb_charset

        """
        pass

    def test_set_smb_netbios_name(self):
        """Test case for set_smb_netbios_name

        """
        pass

    def test_set_smb_trusted_domains(self):
        """Test case for set_smb_trusted_domains

        """
        pass

    def test_show_audit_conf(self):
        """Test case for show_audit_conf

        """
        pass

    def test_start_defrag(self):
        """Test case for start_defrag

        """
        pass

    def test_start_trim(self):
        """Test case for start_trim

        """
        pass

    def test_stop_defrag(self):
        """Test case for stop_defrag

        """
        pass

    def test_stop_trim(self):
        """Test case for stop_trim

        """
        pass

    def test_update_zcs_settings(self):
        """Test case for update_zcs_settings

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20068ResponsePoolSsd(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reserved_capacity': 'float',
        'usable_capacity': 'float',
        'used_capacity': 'float',
        'free_capacity': 'float',
        'used_by_data_capacity': 'float',
        'used_by_metadata_capacity': 'float',
        'usable_shrinked_capacity': 'float',
        'data_segments_capacity': 'float',
        'metadata_segments_capacity': 'float',
        'stale_capacity': 'float',
        'free_segments_capacity': 'float',
        'free_segments_percent': 'float'
    }

    attribute_map = {
        'reserved_capacity': 'reserved_capacity',
        'usable_capacity': 'usable_capacity',
        'used_capacity': 'used_capacity',
        'free_capacity': 'free_capacity',
        'used_by_data_capacity': 'used_by_data_capacity',
        'used_by_metadata_capacity': 'used_by_metadata_capacity',
        'usable_shrinked_capacity': 'usable_shrinked_capacity',
        'data_segments_capacity': 'data_segments_capacity',
        'metadata_segments_capacity': 'metadata_segments_capacity',
        'stale_capacity': 'stale_capacity',
        'free_segments_capacity': 'free_segments_capacity',
        'free_segments_percent': 'free_segments_percent'
    }

    def __init__(self, reserved_capacity=None, usable_capacity=None, used_capacity=None, free_capacity=None, used_by_data_capacity=None, used_by_metadata_capacity=None, usable_shrinked_capacity=None, data_segments_capacity=None, metadata_segments_capacity=None, stale_capacity=None, free_segments_capacity=None, free_segments_percent=None, _configuration=None):  # noqa: E501
        """InlineResponse20068ResponsePoolSsd - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._reserved_capacity = None
        self._usable_capacity = None
        self._used_capacity = None
        self._free_capacity = None
        self._used_by_data_capacity = None
        self._used_by_metadata_capacity = None
        self._usable_shrinked_capacity = None
        self._data_segments_capacity = None
        self._metadata_segments_capacity = None
        self._stale_capacity = None
        self._free_segments_capacity = None
        self._free_segments_percent = None
        self.discriminator = None

        if reserved_capacity is not None:
            self.reserved_capacity = reserved_capacity
        if usable_capacity is not None:
            self.usable_capacity = usable_capacity
        if used_capacity is not None:
            self.used_capacity = used_capacity
        if free_capacity is not None:
            self.free_capacity = free_capacity
        if used_by_data_capacity is not None:
            self.used_by_data_capacity = used_by_data_capacity
        if used_by_metadata_capacity is not None:
            self.used_by_metadata_capacity = used_by_metadata_capacity
        if usable_shrinked_capacity is not None:
            self.usable_shrinked_capacity = usable_shrinked_capacity
        if data_segments_capacity is not None:
            self.data_segments_capacity = data_segments_capacity
        if metadata_segments_capacity is not None:
            self.metadata_segments_capacity = metadata_segments_capacity
        if stale_capacity is not None:
            self.stale_capacity = stale_capacity
        if free_segments_capacity is not None:
            self.free_segments_capacity = free_segments_capacity
        if free_segments_percent is not None:
            self.free_segments_percent = free_segments_percent

    @property
    def reserved_capacity(self):
        """Gets the reserved_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The reserved_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._reserved_capacity

    @reserved_capacity.setter
    def reserved_capacity(self, reserved_capacity):
        """Sets the reserved_capacity of this InlineResponse20068ResponsePoolSsd.


        :param reserved_capacity: The reserved_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._reserved_capacity = reserved_capacity

    @property
    def usable_capacity(self):
        """Gets the usable_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The usable_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._usable_capacity

    @usable_capacity.setter
    def usable_capacity(self, usable_capacity):
        """Sets the usable_capacity of this InlineResponse20068ResponsePoolSsd.


        :param usable_capacity: The usable_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._usable_capacity = usable_capacity

    @property
    def used_capacity(self):
        """Gets the used_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The used_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._used_capacity

    @used_capacity.setter
    def used_capacity(self, used_capacity):
        """Sets the used_capacity of this InlineResponse20068ResponsePoolSsd.


        :param used_capacity: The used_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._used_capacity = used_capacity

    @property
    def free_capacity(self):
        """Gets the free_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The free_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._free_capacity

    @free_capacity.setter
    def free_capacity(self, free_capacity):
        """Sets the free_capacity of this InlineResponse20068ResponsePoolSsd.


        :param free_capacity: The free_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._free_capacity = free_capacity

    @property
    def used_by_data_capacity(self):
        """Gets the used_by_data_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The used_by_data_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._used_by_data_capacity

    @used_by_data_capacity.setter
    def used_by_data_capacity(self, used_by_data_capacity):
        """Sets the used_by_data_capacity of this InlineResponse20068ResponsePoolSsd.


        :param used_by_data_capacity: The used_by_data_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._used_by_data_capacity = used_by_data_capacity

    @property
    def used_by_metadata_capacity(self):
        """Gets the used_by_metadata_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The used_by_metadata_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._used_by_metadata_capacity

    @used_by_metadata_capacity.setter
    def used_by_metadata_capacity(self, used_by_metadata_capacity):
        """Sets the used_by_metadata_capacity of this InlineResponse20068ResponsePoolSsd.


        :param used_by_metadata_capacity: The used_by_metadata_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._used_by_metadata_capacity = used_by_metadata_capacity

    @property
    def usable_shrinked_capacity(self):
        """Gets the usable_shrinked_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The usable_shrinked_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._usable_shrinked_capacity

    @usable_shrinked_capacity.setter
    def usable_shrinked_capacity(self, usable_shrinked_capacity):
        """Sets the usable_shrinked_capacity of this InlineResponse20068ResponsePoolSsd.


        :param usable_shrinked_capacity: The usable_shrinked_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._usable_shrinked_capacity = usable_shrinked_capacity

    @property
    def data_segments_capacity(self):
        """Gets the data_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The data_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._data_segments_capacity

    @data_segments_capacity.setter
    def data_segments_capacity(self, data_segments_capacity):
        """Sets the data_segments_capacity of this InlineResponse20068ResponsePoolSsd.


        :param data_segments_capacity: The data_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._data_segments_capacity = data_segments_capacity

    @property
    def metadata_segments_capacity(self):
        """Gets the metadata_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The metadata_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._metadata_segments_capacity

    @metadata_segments_capacity.setter
    def metadata_segments_capacity(self, metadata_segments_capacity):
        """Sets the metadata_segments_capacity of this InlineResponse20068ResponsePoolSsd.


        :param metadata_segments_capacity: The metadata_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._metadata_segments_capacity = metadata_segments_capacity

    @property
    def stale_capacity(self):
        """Gets the stale_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The stale_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._stale_capacity

    @stale_capacity.setter
    def stale_capacity(self, stale_capacity):
        """Sets the stale_capacity of this InlineResponse20068ResponsePoolSsd.


        :param stale_capacity: The stale_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._stale_capacity = stale_capacity

    @property
    def free_segments_capacity(self):
        """Gets the free_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The free_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._free_segments_capacity

    @free_segments_capacity.setter
    def free_segments_capacity(self, free_segments_capacity):
        """Sets the free_segments_capacity of this InlineResponse20068ResponsePoolSsd.


        :param free_segments_capacity: The free_segments_capacity of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._free_segments_capacity = free_segments_capacity

    @property
    def free_segments_percent(self):
        """Gets the free_segments_percent of this InlineResponse20068ResponsePoolSsd.  # noqa: E501


        :return: The free_segments_percent of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :rtype: float
        """
        return self._free_segments_percent

    @free_segments_percent.setter
    def free_segments_percent(self, free_segments_percent):
        """Sets the free_segments_percent of this InlineResponse20068ResponsePoolSsd.


        :param free_segments_percent: The free_segments_percent of this InlineResponse20068ResponsePoolSsd.  # noqa: E501
        :type: float
        """

        self._free_segments_percent = free_segments_percent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20068ResponsePoolSsd, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20068ResponsePoolSsd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20068ResponsePoolSsd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200129Zioses(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'internal_name': 'str',
        'user': 'str',
        'tenant_name': 'str',
        'description': 'str',
        'status': 'str',
        'engine_type': 'str',
        'vcpus': 'int',
        'ram': 'int',
        'https_termination': 'bool',
        'image': 'str',
        'drives': 'int',
        'cache': 'int',
        'virtual_controllers': 'int',
        'ip_address': 'str',
        'public_ip': 'str',
        'management_url': 'str',
        'storage_policies_count': 'int',
        'metadata_policies_count': 'int',
        'accounts_count': 'int',
        'users_count': 'int',
        'containers_count': 'int',
        'redundancy_status': 'str',
        'objects_count': 'int',
        'active_vc_index': 'int',
        'network_configuration': 'InlineResponse200129NetworkConfiguration',
        'created_at': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'internal_name': 'internal_name',
        'user': 'user',
        'tenant_name': 'tenant_name',
        'description': 'description',
        'status': 'status',
        'engine_type': 'engine_type',
        'vcpus': 'vcpus',
        'ram': 'ram',
        'https_termination': 'https_termination',
        'image': 'image',
        'drives': 'drives',
        'cache': 'cache',
        'virtual_controllers': 'virtual_controllers',
        'ip_address': 'ip_address',
        'public_ip': 'public_ip',
        'management_url': 'management_url',
        'storage_policies_count': 'storage_policies_count',
        'metadata_policies_count': 'metadata_policies_count',
        'accounts_count': 'accounts_count',
        'users_count': 'users_count',
        'containers_count': 'containers_count',
        'redundancy_status': 'redundancy_status',
        'objects_count': 'objects_count',
        'active_vc_index': 'active_vc_index',
        'network_configuration': 'network_configuration',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, name=None, internal_name=None, user=None, tenant_name=None, description=None, status=None, engine_type=None, vcpus=None, ram=None, https_termination=None, image=None, drives=None, cache=None, virtual_controllers=None, ip_address=None, public_ip=None, management_url=None, storage_policies_count=None, metadata_policies_count=None, accounts_count=None, users_count=None, containers_count=None, redundancy_status=None, objects_count=None, active_vc_index=None, network_configuration=None, created_at=None, updated_at=None, _configuration=None):  # noqa: E501
        """InlineResponse200129Zioses - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._internal_name = None
        self._user = None
        self._tenant_name = None
        self._description = None
        self._status = None
        self._engine_type = None
        self._vcpus = None
        self._ram = None
        self._https_termination = None
        self._image = None
        self._drives = None
        self._cache = None
        self._virtual_controllers = None
        self._ip_address = None
        self._public_ip = None
        self._management_url = None
        self._storage_policies_count = None
        self._metadata_policies_count = None
        self._accounts_count = None
        self._users_count = None
        self._containers_count = None
        self._redundancy_status = None
        self._objects_count = None
        self._active_vc_index = None
        self._network_configuration = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if internal_name is not None:
            self.internal_name = internal_name
        if user is not None:
            self.user = user
        if tenant_name is not None:
            self.tenant_name = tenant_name
        if description is not None:
            self.description = description
        if status is not None:
            self.status = status
        if engine_type is not None:
            self.engine_type = engine_type
        if vcpus is not None:
            self.vcpus = vcpus
        if ram is not None:
            self.ram = ram
        if https_termination is not None:
            self.https_termination = https_termination
        if image is not None:
            self.image = image
        if drives is not None:
            self.drives = drives
        if cache is not None:
            self.cache = cache
        if virtual_controllers is not None:
            self.virtual_controllers = virtual_controllers
        if ip_address is not None:
            self.ip_address = ip_address
        if public_ip is not None:
            self.public_ip = public_ip
        if management_url is not None:
            self.management_url = management_url
        if storage_policies_count is not None:
            self.storage_policies_count = storage_policies_count
        if metadata_policies_count is not None:
            self.metadata_policies_count = metadata_policies_count
        if accounts_count is not None:
            self.accounts_count = accounts_count
        if users_count is not None:
            self.users_count = users_count
        if containers_count is not None:
            self.containers_count = containers_count
        if redundancy_status is not None:
            self.redundancy_status = redundancy_status
        if objects_count is not None:
            self.objects_count = objects_count
        if active_vc_index is not None:
            self.active_vc_index = active_vc_index
        if network_configuration is not None:
            self.network_configuration = network_configuration
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this InlineResponse200129Zioses.  # noqa: E501


        :return: The id of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse200129Zioses.


        :param id: The id of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InlineResponse200129Zioses.  # noqa: E501


        :return: The name of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200129Zioses.


        :param name: The name of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def internal_name(self):
        """Gets the internal_name of this InlineResponse200129Zioses.  # noqa: E501


        :return: The internal_name of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this InlineResponse200129Zioses.


        :param internal_name: The internal_name of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def user(self):
        """Gets the user of this InlineResponse200129Zioses.  # noqa: E501


        :return: The user of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this InlineResponse200129Zioses.


        :param user: The user of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def tenant_name(self):
        """Gets the tenant_name of this InlineResponse200129Zioses.  # noqa: E501


        :return: The tenant_name of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this InlineResponse200129Zioses.


        :param tenant_name: The tenant_name of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._tenant_name = tenant_name

    @property
    def description(self):
        """Gets the description of this InlineResponse200129Zioses.  # noqa: E501


        :return: The description of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse200129Zioses.


        :param description: The description of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def status(self):
        """Gets the status of this InlineResponse200129Zioses.  # noqa: E501


        :return: The status of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200129Zioses.


        :param status: The status of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def engine_type(self):
        """Gets the engine_type of this InlineResponse200129Zioses.  # noqa: E501


        :return: The engine_type of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._engine_type

    @engine_type.setter
    def engine_type(self, engine_type):
        """Sets the engine_type of this InlineResponse200129Zioses.


        :param engine_type: The engine_type of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._engine_type = engine_type

    @property
    def vcpus(self):
        """Gets the vcpus of this InlineResponse200129Zioses.  # noqa: E501


        :return: The vcpus of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._vcpus

    @vcpus.setter
    def vcpus(self, vcpus):
        """Sets the vcpus of this InlineResponse200129Zioses.


        :param vcpus: The vcpus of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._vcpus = vcpus

    @property
    def ram(self):
        """Gets the ram of this InlineResponse200129Zioses.  # noqa: E501


        :return: The ram of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this InlineResponse200129Zioses.


        :param ram: The ram of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._ram = ram

    @property
    def https_termination(self):
        """Gets the https_termination of this InlineResponse200129Zioses.  # noqa: E501


        :return: The https_termination of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: bool
        """
        return self._https_termination

    @https_termination.setter
    def https_termination(self, https_termination):
        """Sets the https_termination of this InlineResponse200129Zioses.


        :param https_termination: The https_termination of this InlineResponse200129Zioses.  # noqa: E501
        :type: bool
        """

        self._https_termination = https_termination

    @property
    def image(self):
        """Gets the image of this InlineResponse200129Zioses.  # noqa: E501


        :return: The image of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this InlineResponse200129Zioses.


        :param image: The image of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def drives(self):
        """Gets the drives of this InlineResponse200129Zioses.  # noqa: E501


        :return: The drives of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this InlineResponse200129Zioses.


        :param drives: The drives of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._drives = drives

    @property
    def cache(self):
        """Gets the cache of this InlineResponse200129Zioses.  # noqa: E501


        :return: The cache of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse200129Zioses.


        :param cache: The cache of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._cache = cache

    @property
    def virtual_controllers(self):
        """Gets the virtual_controllers of this InlineResponse200129Zioses.  # noqa: E501


        :return: The virtual_controllers of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._virtual_controllers

    @virtual_controllers.setter
    def virtual_controllers(self, virtual_controllers):
        """Sets the virtual_controllers of this InlineResponse200129Zioses.


        :param virtual_controllers: The virtual_controllers of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._virtual_controllers = virtual_controllers

    @property
    def ip_address(self):
        """Gets the ip_address of this InlineResponse200129Zioses.  # noqa: E501


        :return: The ip_address of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this InlineResponse200129Zioses.


        :param ip_address: The ip_address of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def public_ip(self):
        """Gets the public_ip of this InlineResponse200129Zioses.  # noqa: E501


        :return: The public_ip of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._public_ip

    @public_ip.setter
    def public_ip(self, public_ip):
        """Sets the public_ip of this InlineResponse200129Zioses.


        :param public_ip: The public_ip of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._public_ip = public_ip

    @property
    def management_url(self):
        """Gets the management_url of this InlineResponse200129Zioses.  # noqa: E501


        :return: The management_url of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this InlineResponse200129Zioses.


        :param management_url: The management_url of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def storage_policies_count(self):
        """Gets the storage_policies_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The storage_policies_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._storage_policies_count

    @storage_policies_count.setter
    def storage_policies_count(self, storage_policies_count):
        """Sets the storage_policies_count of this InlineResponse200129Zioses.


        :param storage_policies_count: The storage_policies_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._storage_policies_count = storage_policies_count

    @property
    def metadata_policies_count(self):
        """Gets the metadata_policies_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The metadata_policies_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._metadata_policies_count

    @metadata_policies_count.setter
    def metadata_policies_count(self, metadata_policies_count):
        """Sets the metadata_policies_count of this InlineResponse200129Zioses.


        :param metadata_policies_count: The metadata_policies_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._metadata_policies_count = metadata_policies_count

    @property
    def accounts_count(self):
        """Gets the accounts_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The accounts_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._accounts_count

    @accounts_count.setter
    def accounts_count(self, accounts_count):
        """Sets the accounts_count of this InlineResponse200129Zioses.


        :param accounts_count: The accounts_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._accounts_count = accounts_count

    @property
    def users_count(self):
        """Gets the users_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The users_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._users_count

    @users_count.setter
    def users_count(self, users_count):
        """Sets the users_count of this InlineResponse200129Zioses.


        :param users_count: The users_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._users_count = users_count

    @property
    def containers_count(self):
        """Gets the containers_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The containers_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._containers_count

    @containers_count.setter
    def containers_count(self, containers_count):
        """Sets the containers_count of this InlineResponse200129Zioses.


        :param containers_count: The containers_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._containers_count = containers_count

    @property
    def redundancy_status(self):
        """Gets the redundancy_status of this InlineResponse200129Zioses.  # noqa: E501


        :return: The redundancy_status of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._redundancy_status

    @redundancy_status.setter
    def redundancy_status(self, redundancy_status):
        """Sets the redundancy_status of this InlineResponse200129Zioses.


        :param redundancy_status: The redundancy_status of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._redundancy_status = redundancy_status

    @property
    def objects_count(self):
        """Gets the objects_count of this InlineResponse200129Zioses.  # noqa: E501


        :return: The objects_count of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._objects_count

    @objects_count.setter
    def objects_count(self, objects_count):
        """Sets the objects_count of this InlineResponse200129Zioses.


        :param objects_count: The objects_count of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._objects_count = objects_count

    @property
    def active_vc_index(self):
        """Gets the active_vc_index of this InlineResponse200129Zioses.  # noqa: E501


        :return: The active_vc_index of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: int
        """
        return self._active_vc_index

    @active_vc_index.setter
    def active_vc_index(self, active_vc_index):
        """Sets the active_vc_index of this InlineResponse200129Zioses.


        :param active_vc_index: The active_vc_index of this InlineResponse200129Zioses.  # noqa: E501
        :type: int
        """

        self._active_vc_index = active_vc_index

    @property
    def network_configuration(self):
        """Gets the network_configuration of this InlineResponse200129Zioses.  # noqa: E501


        :return: The network_configuration of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: InlineResponse200129NetworkConfiguration
        """
        return self._network_configuration

    @network_configuration.setter
    def network_configuration(self, network_configuration):
        """Sets the network_configuration of this InlineResponse200129Zioses.


        :param network_configuration: The network_configuration of this InlineResponse200129Zioses.  # noqa: E501
        :type: InlineResponse200129NetworkConfiguration
        """

        self._network_configuration = network_configuration

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200129Zioses.  # noqa: E501


        :return: The created_at of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200129Zioses.


        :param created_at: The created_at of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this InlineResponse200129Zioses.  # noqa: E501


        :return: The updated_at of this InlineResponse200129Zioses.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this InlineResponse200129Zioses.


        :param updated_at: The updated_at of this InlineResponse200129Zioses.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200129Zioses, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200129Zioses):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200129Zioses):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200134ZiosStoragePolicies(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'internal_name': 'str',
        'name': 'str',
        'status': 'str',
        'protection': 'str',
        'default': 'bool',
        'health_status': 'str',
        'health_percentage': 'int',
        'ring_balance': 'InlineResponse200134RingBalance',
        'used_capacity': 'int',
        'free_capacity': 'int'
    }

    attribute_map = {
        'id': 'id',
        'internal_name': 'internal_name',
        'name': 'name',
        'status': 'status',
        'protection': 'protection',
        'default': 'default',
        'health_status': 'health_status',
        'health_percentage': 'health_percentage',
        'ring_balance': 'ring_balance',
        'used_capacity': 'used_capacity',
        'free_capacity': 'free_capacity'
    }

    def __init__(self, id=None, internal_name=None, name=None, status=None, protection=None, default=None, health_status=None, health_percentage=None, ring_balance=None, used_capacity=None, free_capacity=None, _configuration=None):  # noqa: E501
        """InlineResponse200134ZiosStoragePolicies - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._internal_name = None
        self._name = None
        self._status = None
        self._protection = None
        self._default = None
        self._health_status = None
        self._health_percentage = None
        self._ring_balance = None
        self._used_capacity = None
        self._free_capacity = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if internal_name is not None:
            self.internal_name = internal_name
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if protection is not None:
            self.protection = protection
        if default is not None:
            self.default = default
        if health_status is not None:
            self.health_status = health_status
        if health_percentage is not None:
            self.health_percentage = health_percentage
        if ring_balance is not None:
            self.ring_balance = ring_balance
        if used_capacity is not None:
            self.used_capacity = used_capacity
        if free_capacity is not None:
            self.free_capacity = free_capacity

    @property
    def id(self):
        """Gets the id of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The id of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse200134ZiosStoragePolicies.


        :param id: The id of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def internal_name(self):
        """Gets the internal_name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The internal_name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this InlineResponse200134ZiosStoragePolicies.


        :param internal_name: The internal_name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def name(self):
        """Gets the name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200134ZiosStoragePolicies.


        :param name: The name of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200134ZiosStoragePolicies.


        :param status: The status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def protection(self):
        """Gets the protection of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The protection of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._protection

    @protection.setter
    def protection(self, protection):
        """Sets the protection of this InlineResponse200134ZiosStoragePolicies.


        :param protection: The protection of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._protection = protection

    @property
    def default(self):
        """Gets the default of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The default of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this InlineResponse200134ZiosStoragePolicies.


        :param default: The default of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def health_status(self):
        """Gets the health_status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The health_status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: str
        """
        return self._health_status

    @health_status.setter
    def health_status(self, health_status):
        """Sets the health_status of this InlineResponse200134ZiosStoragePolicies.


        :param health_status: The health_status of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: str
        """

        self._health_status = health_status

    @property
    def health_percentage(self):
        """Gets the health_percentage of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The health_percentage of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._health_percentage

    @health_percentage.setter
    def health_percentage(self, health_percentage):
        """Sets the health_percentage of this InlineResponse200134ZiosStoragePolicies.


        :param health_percentage: The health_percentage of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: int
        """

        self._health_percentage = health_percentage

    @property
    def ring_balance(self):
        """Gets the ring_balance of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The ring_balance of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: InlineResponse200134RingBalance
        """
        return self._ring_balance

    @ring_balance.setter
    def ring_balance(self, ring_balance):
        """Sets the ring_balance of this InlineResponse200134ZiosStoragePolicies.


        :param ring_balance: The ring_balance of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: InlineResponse200134RingBalance
        """

        self._ring_balance = ring_balance

    @property
    def used_capacity(self):
        """Gets the used_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The used_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._used_capacity

    @used_capacity.setter
    def used_capacity(self, used_capacity):
        """Sets the used_capacity of this InlineResponse200134ZiosStoragePolicies.


        :param used_capacity: The used_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: int
        """

        self._used_capacity = used_capacity

    @property
    def free_capacity(self):
        """Gets the free_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501


        :return: The free_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :rtype: int
        """
        return self._free_capacity

    @free_capacity.setter
    def free_capacity(self, free_capacity):
        """Sets the free_capacity of this InlineResponse200134ZiosStoragePolicies.


        :param free_capacity: The free_capacity of this InlineResponse200134ZiosStoragePolicies.  # noqa: E501
        :type: int
        """

        self._free_capacity = free_capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200134ZiosStoragePolicies, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200134ZiosStoragePolicies):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200134ZiosStoragePolicies):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateVolumeNasOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dedupe': 'str',
        'compress': 'str',
        'atimeupdate': 'str',
        'mountsync': 'str',
        'smbguest': 'str',
        'smbonly': 'str',
        'smbwindowsacl': 'str',
        'smbfilecreatemask': 'str',
        'smbdircreatemask': 'str',
        'smbbrowseable': 'str',
        'smbhiddenfiles': 'str',
        'smbhideunreadable': 'str',
        'smbhidedotfiles': 'str',
        'smbhideunwriteable': 'str',
        'smbmaparchive': 'str',
        'smbaiosize': 'str',
        'smbencryptionmode': 'str',
        'smbenableoplocks': 'str',
        'smbmanglednames': 'str',
        'smbcasesensitive': 'str',
        'nfsrootsquash': 'str',
        'nfsallsquash': 'str',
        'nfsanongid': 'int',
        'nfsanonuid': 'int',
        'readaheadkb': 'str',
        'force': 'str',
        'auditenable': 'str',
        'flcenabled': 'str',
        'mtr_histograms': 'str',
        'write_mbps_capping': 'int',
        'read_mbps_capping': 'int',
        'write_iops_capping': 'int',
        'read_iops_capping': 'int',
        'managedfor': 'str'
    }

    attribute_map = {
        'dedupe': 'dedupe',
        'compress': 'compress',
        'atimeupdate': 'atimeupdate',
        'mountsync': 'mountsync',
        'smbguest': 'smbguest',
        'smbonly': 'smbonly',
        'smbwindowsacl': 'smbwindowsacl',
        'smbfilecreatemask': 'smbfilecreatemask',
        'smbdircreatemask': 'smbdircreatemask',
        'smbbrowseable': 'smbbrowseable',
        'smbhiddenfiles': 'smbhiddenfiles',
        'smbhideunreadable': 'smbhideunreadable',
        'smbhidedotfiles': 'smbhidedotfiles',
        'smbhideunwriteable': 'smbhideunwriteable',
        'smbmaparchive': 'smbmaparchive',
        'smbaiosize': 'smbaiosize',
        'smbencryptionmode': 'smbencryptionmode',
        'smbenableoplocks': 'smbenableoplocks',
        'smbmanglednames': 'smbmanglednames',
        'smbcasesensitive': 'smbcasesensitive',
        'nfsrootsquash': 'nfsrootsquash',
        'nfsallsquash': 'nfsallsquash',
        'nfsanongid': 'nfsanongid',
        'nfsanonuid': 'nfsanonuid',
        'readaheadkb': 'readaheadkb',
        'force': 'force',
        'auditenable': 'auditenable',
        'flcenabled': 'flcenabled',
        'mtr_histograms': 'mtr_histograms',
        'write_mbps_capping': 'write_mbps_capping',
        'read_mbps_capping': 'read_mbps_capping',
        'write_iops_capping': 'write_iops_capping',
        'read_iops_capping': 'read_iops_capping',
        'managedfor': 'managedfor'
    }

    def __init__(self, dedupe=None, compress=None, atimeupdate=None, mountsync=None, smbguest=None, smbonly=None, smbwindowsacl=None, smbfilecreatemask=None, smbdircreatemask=None, smbbrowseable=None, smbhiddenfiles=None, smbhideunreadable=None, smbhidedotfiles=None, smbhideunwriteable=None, smbmaparchive=None, smbaiosize=None, smbencryptionmode=None, smbenableoplocks=None, smbmanglednames=None, smbcasesensitive=None, nfsrootsquash=None, nfsallsquash=None, nfsanongid=None, nfsanonuid=None, readaheadkb=None, force=None, auditenable=None, flcenabled=None, mtr_histograms=None, write_mbps_capping=None, read_mbps_capping=None, write_iops_capping=None, read_iops_capping=None, managedfor=None, _configuration=None):  # noqa: E501
        """UpdateVolumeNasOptions - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._dedupe = None
        self._compress = None
        self._atimeupdate = None
        self._mountsync = None
        self._smbguest = None
        self._smbonly = None
        self._smbwindowsacl = None
        self._smbfilecreatemask = None
        self._smbdircreatemask = None
        self._smbbrowseable = None
        self._smbhiddenfiles = None
        self._smbhideunreadable = None
        self._smbhidedotfiles = None
        self._smbhideunwriteable = None
        self._smbmaparchive = None
        self._smbaiosize = None
        self._smbencryptionmode = None
        self._smbenableoplocks = None
        self._smbmanglednames = None
        self._smbcasesensitive = None
        self._nfsrootsquash = None
        self._nfsallsquash = None
        self._nfsanongid = None
        self._nfsanonuid = None
        self._readaheadkb = None
        self._force = None
        self._auditenable = None
        self._flcenabled = None
        self._mtr_histograms = None
        self._write_mbps_capping = None
        self._read_mbps_capping = None
        self._write_iops_capping = None
        self._read_iops_capping = None
        self._managedfor = None
        self.discriminator = None

        if dedupe is not None:
            self.dedupe = dedupe
        if compress is not None:
            self.compress = compress
        if atimeupdate is not None:
            self.atimeupdate = atimeupdate
        if mountsync is not None:
            self.mountsync = mountsync
        if smbguest is not None:
            self.smbguest = smbguest
        if smbonly is not None:
            self.smbonly = smbonly
        if smbwindowsacl is not None:
            self.smbwindowsacl = smbwindowsacl
        if smbfilecreatemask is not None:
            self.smbfilecreatemask = smbfilecreatemask
        if smbdircreatemask is not None:
            self.smbdircreatemask = smbdircreatemask
        if smbbrowseable is not None:
            self.smbbrowseable = smbbrowseable
        if smbhiddenfiles is not None:
            self.smbhiddenfiles = smbhiddenfiles
        if smbhideunreadable is not None:
            self.smbhideunreadable = smbhideunreadable
        if smbhidedotfiles is not None:
            self.smbhidedotfiles = smbhidedotfiles
        if smbhideunwriteable is not None:
            self.smbhideunwriteable = smbhideunwriteable
        if smbmaparchive is not None:
            self.smbmaparchive = smbmaparchive
        if smbaiosize is not None:
            self.smbaiosize = smbaiosize
        if smbencryptionmode is not None:
            self.smbencryptionmode = smbencryptionmode
        if smbenableoplocks is not None:
            self.smbenableoplocks = smbenableoplocks
        if smbmanglednames is not None:
            self.smbmanglednames = smbmanglednames
        if smbcasesensitive is not None:
            self.smbcasesensitive = smbcasesensitive
        if nfsrootsquash is not None:
            self.nfsrootsquash = nfsrootsquash
        if nfsallsquash is not None:
            self.nfsallsquash = nfsallsquash
        if nfsanongid is not None:
            self.nfsanongid = nfsanongid
        if nfsanonuid is not None:
            self.nfsanonuid = nfsanonuid
        if readaheadkb is not None:
            self.readaheadkb = readaheadkb
        if force is not None:
            self.force = force
        if auditenable is not None:
            self.auditenable = auditenable
        if flcenabled is not None:
            self.flcenabled = flcenabled
        if mtr_histograms is not None:
            self.mtr_histograms = mtr_histograms
        if write_mbps_capping is not None:
            self.write_mbps_capping = write_mbps_capping
        if read_mbps_capping is not None:
            self.read_mbps_capping = read_mbps_capping
        if write_iops_capping is not None:
            self.write_iops_capping = write_iops_capping
        if read_iops_capping is not None:
            self.read_iops_capping = read_iops_capping
        if managedfor is not None:
            self.managedfor = managedfor

    @property
    def dedupe(self):
        """Gets the dedupe of this UpdateVolumeNasOptions.  # noqa: E501

        Enable Dedupe For Volume.  # noqa: E501

        :return: The dedupe of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this UpdateVolumeNasOptions.

        Enable Dedupe For Volume.  # noqa: E501

        :param dedupe: The dedupe of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                dedupe not in allowed_values):
            raise ValueError(
                "Invalid value for `dedupe` ({0}), must be one of {1}"  # noqa: E501
                .format(dedupe, allowed_values)
            )

        self._dedupe = dedupe

    @property
    def compress(self):
        """Gets the compress of this UpdateVolumeNasOptions.  # noqa: E501

        Enable compress For Volume.  # noqa: E501

        :return: The compress of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this UpdateVolumeNasOptions.

        Enable compress For Volume.  # noqa: E501

        :param compress: The compress of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                compress not in allowed_values):
            raise ValueError(
                "Invalid value for `compress` ({0}), must be one of {1}"  # noqa: E501
                .format(compress, allowed_values)
            )

        self._compress = compress

    @property
    def atimeupdate(self):
        """Gets the atimeupdate of this UpdateVolumeNasOptions.  # noqa: E501

        Enable/disable update access times.  # noqa: E501

        :return: The atimeupdate of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._atimeupdate

    @atimeupdate.setter
    def atimeupdate(self, atimeupdate):
        """Sets the atimeupdate of this UpdateVolumeNasOptions.

        Enable/disable update access times.  # noqa: E501

        :param atimeupdate: The atimeupdate of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                atimeupdate not in allowed_values):
            raise ValueError(
                "Invalid value for `atimeupdate` ({0}), must be one of {1}"  # noqa: E501
                .format(atimeupdate, allowed_values)
            )

        self._atimeupdate = atimeupdate

    @property
    def mountsync(self):
        """Gets the mountsync of this UpdateVolumeNasOptions.  # noqa: E501

        Filesystem write policy. YES for Synchronous Writing, NO for Asynchronous Writing.  # noqa: E501

        :return: The mountsync of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._mountsync

    @mountsync.setter
    def mountsync(self, mountsync):
        """Sets the mountsync of this UpdateVolumeNasOptions.

        Filesystem write policy. YES for Synchronous Writing, NO for Asynchronous Writing.  # noqa: E501

        :param mountsync: The mountsync of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mountsync not in allowed_values):
            raise ValueError(
                "Invalid value for `mountsync` ({0}), must be one of {1}"  # noqa: E501
                .format(mountsync, allowed_values)
            )

        self._mountsync = mountsync

    @property
    def smbguest(self):
        """Gets the smbguest of this UpdateVolumeNasOptions.  # noqa: E501

        Allow/disallow SMB guest access for a Share. YES for Synchronous Writing, NO for Asynchronous Writing.  # noqa: E501

        :return: The smbguest of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbguest

    @smbguest.setter
    def smbguest(self, smbguest):
        """Sets the smbguest of this UpdateVolumeNasOptions.

        Allow/disallow SMB guest access for a Share. YES for Synchronous Writing, NO for Asynchronous Writing.  # noqa: E501

        :param smbguest: The smbguest of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbguest not in allowed_values):
            raise ValueError(
                "Invalid value for `smbguest` ({0}), must be one of {1}"  # noqa: E501
                .format(smbguest, allowed_values)
            )

        self._smbguest = smbguest

    @property
    def smbonly(self):
        """Gets the smbonly of this UpdateVolumeNasOptions.  # noqa: E501

        Allow/disallow SMB access only for a share.  # noqa: E501

        :return: The smbonly of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbonly

    @smbonly.setter
    def smbonly(self, smbonly):
        """Sets the smbonly of this UpdateVolumeNasOptions.

        Allow/disallow SMB access only for a share.  # noqa: E501

        :param smbonly: The smbonly of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbonly not in allowed_values):
            raise ValueError(
                "Invalid value for `smbonly` ({0}), must be one of {1}"  # noqa: E501
                .format(smbonly, allowed_values)
            )

        self._smbonly = smbonly

    @property
    def smbwindowsacl(self):
        """Gets the smbwindowsacl of this UpdateVolumeNasOptions.  # noqa: E501

        Enable/disabled enhanced Windows ACL for a Share.  # noqa: E501

        :return: The smbwindowsacl of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbwindowsacl

    @smbwindowsacl.setter
    def smbwindowsacl(self, smbwindowsacl):
        """Sets the smbwindowsacl of this UpdateVolumeNasOptions.

        Enable/disabled enhanced Windows ACL for a Share.  # noqa: E501

        :param smbwindowsacl: The smbwindowsacl of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbwindowsacl not in allowed_values):
            raise ValueError(
                "Invalid value for `smbwindowsacl` ({0}), must be one of {1}"  # noqa: E501
                .format(smbwindowsacl, allowed_values)
            )

        self._smbwindowsacl = smbwindowsacl

    @property
    def smbfilecreatemask(self):
        """Gets the smbfilecreatemask of this UpdateVolumeNasOptions.  # noqa: E501

        Updates file creation permission for a Share.  # noqa: E501

        :return: The smbfilecreatemask of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbfilecreatemask

    @smbfilecreatemask.setter
    def smbfilecreatemask(self, smbfilecreatemask):
        """Sets the smbfilecreatemask of this UpdateVolumeNasOptions.

        Updates file creation permission for a Share.  # noqa: E501

        :param smbfilecreatemask: The smbfilecreatemask of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """

        self._smbfilecreatemask = smbfilecreatemask

    @property
    def smbdircreatemask(self):
        """Gets the smbdircreatemask of this UpdateVolumeNasOptions.  # noqa: E501

        Updates directory creation permission for a Share.  # noqa: E501

        :return: The smbdircreatemask of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbdircreatemask

    @smbdircreatemask.setter
    def smbdircreatemask(self, smbdircreatemask):
        """Sets the smbdircreatemask of this UpdateVolumeNasOptions.

        Updates directory creation permission for a Share.  # noqa: E501

        :param smbdircreatemask: The smbdircreatemask of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """

        self._smbdircreatemask = smbdircreatemask

    @property
    def smbbrowseable(self):
        """Gets the smbbrowseable of this UpdateVolumeNasOptions.  # noqa: E501

        Allow/disallow SMB to be browseable.  # noqa: E501

        :return: The smbbrowseable of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbbrowseable

    @smbbrowseable.setter
    def smbbrowseable(self, smbbrowseable):
        """Sets the smbbrowseable of this UpdateVolumeNasOptions.

        Allow/disallow SMB to be browseable.  # noqa: E501

        :param smbbrowseable: The smbbrowseable of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbbrowseable not in allowed_values):
            raise ValueError(
                "Invalid value for `smbbrowseable` ({0}), must be one of {1}"  # noqa: E501
                .format(smbbrowseable, allowed_values)
            )

        self._smbbrowseable = smbbrowseable

    @property
    def smbhiddenfiles(self):
        """Gets the smbhiddenfiles of this UpdateVolumeNasOptions.  # noqa: E501

        SMB files to hide.  # noqa: E501

        :return: The smbhiddenfiles of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbhiddenfiles

    @smbhiddenfiles.setter
    def smbhiddenfiles(self, smbhiddenfiles):
        """Sets the smbhiddenfiles of this UpdateVolumeNasOptions.

        SMB files to hide.  # noqa: E501

        :param smbhiddenfiles: The smbhiddenfiles of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """

        self._smbhiddenfiles = smbhiddenfiles

    @property
    def smbhideunreadable(self):
        """Gets the smbhideunreadable of this UpdateVolumeNasOptions.  # noqa: E501

        hide/show SMB unreadable files.  # noqa: E501

        :return: The smbhideunreadable of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbhideunreadable

    @smbhideunreadable.setter
    def smbhideunreadable(self, smbhideunreadable):
        """Sets the smbhideunreadable of this UpdateVolumeNasOptions.

        hide/show SMB unreadable files.  # noqa: E501

        :param smbhideunreadable: The smbhideunreadable of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbhideunreadable not in allowed_values):
            raise ValueError(
                "Invalid value for `smbhideunreadable` ({0}), must be one of {1}"  # noqa: E501
                .format(smbhideunreadable, allowed_values)
            )

        self._smbhideunreadable = smbhideunreadable

    @property
    def smbhidedotfiles(self):
        """Gets the smbhidedotfiles of this UpdateVolumeNasOptions.  # noqa: E501

        hide/show SMB dot files.  # noqa: E501

        :return: The smbhidedotfiles of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbhidedotfiles

    @smbhidedotfiles.setter
    def smbhidedotfiles(self, smbhidedotfiles):
        """Sets the smbhidedotfiles of this UpdateVolumeNasOptions.

        hide/show SMB dot files.  # noqa: E501

        :param smbhidedotfiles: The smbhidedotfiles of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbhidedotfiles not in allowed_values):
            raise ValueError(
                "Invalid value for `smbhidedotfiles` ({0}), must be one of {1}"  # noqa: E501
                .format(smbhidedotfiles, allowed_values)
            )

        self._smbhidedotfiles = smbhidedotfiles

    @property
    def smbhideunwriteable(self):
        """Gets the smbhideunwriteable of this UpdateVolumeNasOptions.  # noqa: E501

        hide/show SMB unwriteable files.  # noqa: E501

        :return: The smbhideunwriteable of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbhideunwriteable

    @smbhideunwriteable.setter
    def smbhideunwriteable(self, smbhideunwriteable):
        """Sets the smbhideunwriteable of this UpdateVolumeNasOptions.

        hide/show SMB unwriteable files.  # noqa: E501

        :param smbhideunwriteable: The smbhideunwriteable of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbhideunwriteable not in allowed_values):
            raise ValueError(
                "Invalid value for `smbhideunwriteable` ({0}), must be one of {1}"  # noqa: E501
                .format(smbhideunwriteable, allowed_values)
            )

        self._smbhideunwriteable = smbhideunwriteable

    @property
    def smbmaparchive(self):
        """Gets the smbmaparchive of this UpdateVolumeNasOptions.  # noqa: E501

        Allow/disallow map archive for smb Share.  # noqa: E501

        :return: The smbmaparchive of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbmaparchive

    @smbmaparchive.setter
    def smbmaparchive(self, smbmaparchive):
        """Sets the smbmaparchive of this UpdateVolumeNasOptions.

        Allow/disallow map archive for smb Share.  # noqa: E501

        :param smbmaparchive: The smbmaparchive of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbmaparchive not in allowed_values):
            raise ValueError(
                "Invalid value for `smbmaparchive` ({0}), must be one of {1}"  # noqa: E501
                .format(smbmaparchive, allowed_values)
            )

        self._smbmaparchive = smbmaparchive

    @property
    def smbaiosize(self):
        """Gets the smbaiosize of this UpdateVolumeNasOptions.  # noqa: E501


        :return: The smbaiosize of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbaiosize

    @smbaiosize.setter
    def smbaiosize(self, smbaiosize):
        """Sets the smbaiosize of this UpdateVolumeNasOptions.


        :param smbaiosize: The smbaiosize of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """

        self._smbaiosize = smbaiosize

    @property
    def smbencryptionmode(self):
        """Gets the smbencryptionmode of this UpdateVolumeNasOptions.  # noqa: E501

        Set encryption mode for smb Share.  # noqa: E501

        :return: The smbencryptionmode of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbencryptionmode

    @smbencryptionmode.setter
    def smbencryptionmode(self, smbencryptionmode):
        """Sets the smbencryptionmode of this UpdateVolumeNasOptions.

        Set encryption mode for smb Share.  # noqa: E501

        :param smbencryptionmode: The smbencryptionmode of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["off", "desired", "required"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbencryptionmode not in allowed_values):
            raise ValueError(
                "Invalid value for `smbencryptionmode` ({0}), must be one of {1}"  # noqa: E501
                .format(smbencryptionmode, allowed_values)
            )

        self._smbencryptionmode = smbencryptionmode

    @property
    def smbenableoplocks(self):
        """Gets the smbenableoplocks of this UpdateVolumeNasOptions.  # noqa: E501

        Set if smb oplocks enabled.  # noqa: E501

        :return: The smbenableoplocks of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbenableoplocks

    @smbenableoplocks.setter
    def smbenableoplocks(self, smbenableoplocks):
        """Sets the smbenableoplocks of this UpdateVolumeNasOptions.

        Set if smb oplocks enabled.  # noqa: E501

        :param smbenableoplocks: The smbenableoplocks of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbenableoplocks not in allowed_values):
            raise ValueError(
                "Invalid value for `smbenableoplocks` ({0}), must be one of {1}"  # noqa: E501
                .format(smbenableoplocks, allowed_values)
            )

        self._smbenableoplocks = smbenableoplocks

    @property
    def smbmanglednames(self):
        """Gets the smbmanglednames of this UpdateVolumeNasOptions.  # noqa: E501

        Set mangling unsupported filenames handling.  # noqa: E501

        :return: The smbmanglednames of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbmanglednames

    @smbmanglednames.setter
    def smbmanglednames(self, smbmanglednames):
        """Sets the smbmanglednames of this UpdateVolumeNasOptions.

        Set mangling unsupported filenames handling.  # noqa: E501

        :param smbmanglednames: The smbmanglednames of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO", "ILLEGAL"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbmanglednames not in allowed_values):
            raise ValueError(
                "Invalid value for `smbmanglednames` ({0}), must be one of {1}"  # noqa: E501
                .format(smbmanglednames, allowed_values)
            )

        self._smbmanglednames = smbmanglednames

    @property
    def smbcasesensitive(self):
        """Gets the smbcasesensitive of this UpdateVolumeNasOptions.  # noqa: E501

        Set file names case sensitivity.  # noqa: E501

        :return: The smbcasesensitive of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._smbcasesensitive

    @smbcasesensitive.setter
    def smbcasesensitive(self, smbcasesensitive):
        """Sets the smbcasesensitive of this UpdateVolumeNasOptions.

        Set file names case sensitivity.  # noqa: E501

        :param smbcasesensitive: The smbcasesensitive of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO", "AUTO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                smbcasesensitive not in allowed_values):
            raise ValueError(
                "Invalid value for `smbcasesensitive` ({0}), must be one of {1}"  # noqa: E501
                .format(smbcasesensitive, allowed_values)
            )

        self._smbcasesensitive = smbcasesensitive

    @property
    def nfsrootsquash(self):
        """Gets the nfsrootsquash of this UpdateVolumeNasOptions.  # noqa: E501

        Set root squash for nfs mount  # noqa: E501

        :return: The nfsrootsquash of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._nfsrootsquash

    @nfsrootsquash.setter
    def nfsrootsquash(self, nfsrootsquash):
        """Sets the nfsrootsquash of this UpdateVolumeNasOptions.

        Set root squash for nfs mount  # noqa: E501

        :param nfsrootsquash: The nfsrootsquash of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                nfsrootsquash not in allowed_values):
            raise ValueError(
                "Invalid value for `nfsrootsquash` ({0}), must be one of {1}"  # noqa: E501
                .format(nfsrootsquash, allowed_values)
            )

        self._nfsrootsquash = nfsrootsquash

    @property
    def nfsallsquash(self):
        """Gets the nfsallsquash of this UpdateVolumeNasOptions.  # noqa: E501

        Set all squash for nfs mount  # noqa: E501

        :return: The nfsallsquash of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._nfsallsquash

    @nfsallsquash.setter
    def nfsallsquash(self, nfsallsquash):
        """Sets the nfsallsquash of this UpdateVolumeNasOptions.

        Set all squash for nfs mount  # noqa: E501

        :param nfsallsquash: The nfsallsquash of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                nfsallsquash not in allowed_values):
            raise ValueError(
                "Invalid value for `nfsallsquash` ({0}), must be one of {1}"  # noqa: E501
                .format(nfsallsquash, allowed_values)
            )

        self._nfsallsquash = nfsallsquash

    @property
    def nfsanongid(self):
        """Gets the nfsanongid of this UpdateVolumeNasOptions.  # noqa: E501

        Set anonymous GID for nfs mount (0 is reserved for default)  # noqa: E501

        :return: The nfsanongid of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._nfsanongid

    @nfsanongid.setter
    def nfsanongid(self, nfsanongid):
        """Sets the nfsanongid of this UpdateVolumeNasOptions.

        Set anonymous GID for nfs mount (0 is reserved for default)  # noqa: E501

        :param nfsanongid: The nfsanongid of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._nfsanongid = nfsanongid

    @property
    def nfsanonuid(self):
        """Gets the nfsanonuid of this UpdateVolumeNasOptions.  # noqa: E501

        Set anonymous UID for nfs mount (0 is reserved for default)  # noqa: E501

        :return: The nfsanonuid of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._nfsanonuid

    @nfsanonuid.setter
    def nfsanonuid(self, nfsanonuid):
        """Sets the nfsanonuid of this UpdateVolumeNasOptions.

        Set anonymous UID for nfs mount (0 is reserved for default)  # noqa: E501

        :param nfsanonuid: The nfsanonuid of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._nfsanonuid = nfsanonuid

    @property
    def readaheadkb(self):
        """Gets the readaheadkb of this UpdateVolumeNasOptions.  # noqa: E501

        Update Read Ahead Value (KB)  # noqa: E501

        :return: The readaheadkb of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._readaheadkb

    @readaheadkb.setter
    def readaheadkb(self, readaheadkb):
        """Sets the readaheadkb of this UpdateVolumeNasOptions.

        Update Read Ahead Value (KB)  # noqa: E501

        :param readaheadkb: The readaheadkb of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["16", "64", "128", "256", "512"]  # noqa: E501
        if (self._configuration.client_side_validation and
                readaheadkb not in allowed_values):
            raise ValueError(
                "Invalid value for `readaheadkb` ({0}), must be one of {1}"  # noqa: E501
                .format(readaheadkb, allowed_values)
            )

        self._readaheadkb = readaheadkb

    @property
    def force(self):
        """Gets the force of this UpdateVolumeNasOptions.  # noqa: E501

        Update volume parameters even if volume is attached to a server. Default: NO.  # noqa: E501

        :return: The force of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this UpdateVolumeNasOptions.

        Update volume parameters even if volume is attached to a server. Default: NO.  # noqa: E501

        :param force: The force of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    @property
    def auditenable(self):
        """Gets the auditenable of this UpdateVolumeNasOptions.  # noqa: E501

        Enable file access auditing on the volume.  # noqa: E501

        :return: The auditenable of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._auditenable

    @auditenable.setter
    def auditenable(self, auditenable):
        """Sets the auditenable of this UpdateVolumeNasOptions.

        Enable file access auditing on the volume.  # noqa: E501

        :param auditenable: The auditenable of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                auditenable not in allowed_values):
            raise ValueError(
                "Invalid value for `auditenable` ({0}), must be one of {1}"  # noqa: E501
                .format(auditenable, allowed_values)
            )

        self._auditenable = auditenable

    @property
    def flcenabled(self):
        """Gets the flcenabled of this UpdateVolumeNasOptions.  # noqa: E501

        Required FLC indexing state.  # noqa: E501

        :return: The flcenabled of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._flcenabled

    @flcenabled.setter
    def flcenabled(self, flcenabled):
        """Sets the flcenabled of this UpdateVolumeNasOptions.

        Required FLC indexing state.  # noqa: E501

        :param flcenabled: The flcenabled of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["enable", "disable", "resume", "pause"]  # noqa: E501
        if (self._configuration.client_side_validation and
                flcenabled not in allowed_values):
            raise ValueError(
                "Invalid value for `flcenabled` ({0}), must be one of {1}"  # noqa: E501
                .format(flcenabled, allowed_values)
            )

        self._flcenabled = flcenabled

    @property
    def mtr_histograms(self):
        """Gets the mtr_histograms of this UpdateVolumeNasOptions.  # noqa: E501

        Configure IO distribution by size analysis on the volume.  # noqa: E501

        :return: The mtr_histograms of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._mtr_histograms

    @mtr_histograms.setter
    def mtr_histograms(self, mtr_histograms):
        """Sets the mtr_histograms of this UpdateVolumeNasOptions.

        Configure IO distribution by size analysis on the volume.  # noqa: E501

        :param mtr_histograms: The mtr_histograms of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mtr_histograms not in allowed_values):
            raise ValueError(
                "Invalid value for `mtr_histograms` ({0}), must be one of {1}"  # noqa: E501
                .format(mtr_histograms, allowed_values)
            )

        self._mtr_histograms = mtr_histograms

    @property
    def write_mbps_capping(self):
        """Gets the write_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501

        Block only.  # noqa: E501

        :return: The write_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._write_mbps_capping

    @write_mbps_capping.setter
    def write_mbps_capping(self, write_mbps_capping):
        """Sets the write_mbps_capping of this UpdateVolumeNasOptions.

        Block only.  # noqa: E501

        :param write_mbps_capping: The write_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._write_mbps_capping = write_mbps_capping

    @property
    def read_mbps_capping(self):
        """Gets the read_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501

        Block only.  # noqa: E501

        :return: The read_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._read_mbps_capping

    @read_mbps_capping.setter
    def read_mbps_capping(self, read_mbps_capping):
        """Sets the read_mbps_capping of this UpdateVolumeNasOptions.

        Block only.  # noqa: E501

        :param read_mbps_capping: The read_mbps_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._read_mbps_capping = read_mbps_capping

    @property
    def write_iops_capping(self):
        """Gets the write_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501

        Block only.  # noqa: E501

        :return: The write_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._write_iops_capping

    @write_iops_capping.setter
    def write_iops_capping(self, write_iops_capping):
        """Sets the write_iops_capping of this UpdateVolumeNasOptions.

        Block only.  # noqa: E501

        :param write_iops_capping: The write_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._write_iops_capping = write_iops_capping

    @property
    def read_iops_capping(self):
        """Gets the read_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501

        Block only.  # noqa: E501

        :return: The read_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: int
        """
        return self._read_iops_capping

    @read_iops_capping.setter
    def read_iops_capping(self, read_iops_capping):
        """Sets the read_iops_capping of this UpdateVolumeNasOptions.

        Block only.  # noqa: E501

        :param read_iops_capping: The read_iops_capping of this UpdateVolumeNasOptions.  # noqa: E501
        :type: int
        """

        self._read_iops_capping = read_iops_capping

    @property
    def managedfor(self):
        """Gets the managedfor of this UpdateVolumeNasOptions.  # noqa: E501

        For externally managed VPSA, set what the volume is managed for.  # noqa: E501

        :return: The managedfor of this UpdateVolumeNasOptions.  # noqa: E501
        :rtype: str
        """
        return self._managedfor

    @managedfor.setter
    def managedfor(self, managedfor):
        """Sets the managedfor of this UpdateVolumeNasOptions.

        For externally managed VPSA, set what the volume is managed for.  # noqa: E501

        :param managedfor: The managedfor of this UpdateVolumeNasOptions.  # noqa: E501
        :type: str
        """

        self._managedfor = managedfor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateVolumeNasOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVolumeNasOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateVolumeNasOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRaidGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'protection': 'str',
        'disk': 'str',
        'protection_width': 'int',
        'stripe_size': 'int',
        'hot_spare': 'str',
        'force': 'str'
    }

    attribute_map = {
        'display_name': 'display_name',
        'protection': 'protection',
        'disk': 'disk',
        'protection_width': 'protection_width',
        'stripe_size': 'stripe_size',
        'hot_spare': 'hot_spare',
        'force': 'force'
    }

    def __init__(self, display_name=None, protection=None, disk=None, protection_width=None, stripe_size=None, hot_spare=None, force=None, _configuration=None):  # noqa: E501
        """CreateRaidGroup - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._protection = None
        self._disk = None
        self._protection_width = None
        self._stripe_size = None
        self._hot_spare = None
        self._force = None
        self.discriminator = None

        self.display_name = display_name
        self.protection = protection
        self.disk = disk
        if protection_width is not None:
            self.protection_width = protection_width
        if stripe_size is not None:
            self.stripe_size = stripe_size
        if hot_spare is not None:
            self.hot_spare = hot_spare
        if force is not None:
            self.force = force

    @property
    def display_name(self):
        """Gets the display_name of this CreateRaidGroup.  # noqa: E501

        The RAID group display name  # noqa: E501

        :return: The display_name of this CreateRaidGroup.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateRaidGroup.

        The RAID group display name  # noqa: E501

        :param display_name: The display_name of this CreateRaidGroup.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def protection(self):
        """Gets the protection of this CreateRaidGroup.  # noqa: E501

        protection type  # noqa: E501

        :return: The protection of this CreateRaidGroup.  # noqa: E501
        :rtype: str
        """
        return self._protection

    @protection.setter
    def protection(self, protection):
        """Sets the protection of this CreateRaidGroup.

        protection type  # noqa: E501

        :param protection: The protection of this CreateRaidGroup.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and protection is None:
            raise ValueError("Invalid value for `protection`, must not be `None`")  # noqa: E501
        allowed_values = ["RAID1", "RAID5", "RAID6"]  # noqa: E501
        if (self._configuration.client_side_validation and
                protection not in allowed_values):
            raise ValueError(
                "Invalid value for `protection` ({0}), must be one of {1}"  # noqa: E501
                .format(protection, allowed_values)
            )

        self._protection = protection

    @property
    def disk(self):
        """Gets the disk of this CreateRaidGroup.  # noqa: E501

        A comma-separated list of Drive IDs.  # noqa: E501

        :return: The disk of this CreateRaidGroup.  # noqa: E501
        :rtype: str
        """
        return self._disk

    @disk.setter
    def disk(self, disk):
        """Sets the disk of this CreateRaidGroup.

        A comma-separated list of Drive IDs.  # noqa: E501

        :param disk: The disk of this CreateRaidGroup.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and disk is None:
            raise ValueError("Invalid value for `disk`, must not be `None`")  # noqa: E501

        self._disk = disk

    @property
    def protection_width(self):
        """Gets the protection_width of this CreateRaidGroup.  # noqa: E501

        Number of drives in the RAID protection, not including hot spare.  # noqa: E501

        :return: The protection_width of this CreateRaidGroup.  # noqa: E501
        :rtype: int
        """
        return self._protection_width

    @protection_width.setter
    def protection_width(self, protection_width):
        """Sets the protection_width of this CreateRaidGroup.

        Number of drives in the RAID protection, not including hot spare.  # noqa: E501

        :param protection_width: The protection_width of this CreateRaidGroup.  # noqa: E501
        :type: int
        """

        self._protection_width = protection_width

    @property
    def stripe_size(self):
        """Gets the stripe_size of this CreateRaidGroup.  # noqa: E501

        Size of the stripe per Disk. Required for RAID6.  # noqa: E501

        :return: The stripe_size of this CreateRaidGroup.  # noqa: E501
        :rtype: int
        """
        return self._stripe_size

    @stripe_size.setter
    def stripe_size(self, stripe_size):
        """Sets the stripe_size of this CreateRaidGroup.

        Size of the stripe per Disk. Required for RAID6.  # noqa: E501

        :param stripe_size: The stripe_size of this CreateRaidGroup.  # noqa: E501
        :type: int
        """

        self._stripe_size = stripe_size

    @property
    def hot_spare(self):
        """Gets the hot_spare of this CreateRaidGroup.  # noqa: E501


        :return: The hot_spare of this CreateRaidGroup.  # noqa: E501
        :rtype: str
        """
        return self._hot_spare

    @hot_spare.setter
    def hot_spare(self, hot_spare):
        """Sets the hot_spare of this CreateRaidGroup.


        :param hot_spare: The hot_spare of this CreateRaidGroup.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                hot_spare not in allowed_values):
            raise ValueError(
                "Invalid value for `hot_spare` ({0}), must be one of {1}"  # noqa: E501
                .format(hot_spare, allowed_values)
            )

        self._hot_spare = hot_spare

    @property
    def force(self):
        """Gets the force of this CreateRaidGroup.  # noqa: E501


        :return: The force of this CreateRaidGroup.  # noqa: E501
        :rtype: str
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this CreateRaidGroup.


        :param force: The force of this CreateRaidGroup.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                force not in allowed_values):
            raise ValueError(
                "Invalid value for `force` ({0}), must be one of {1}"  # noqa: E501
                .format(force, allowed_values)
            )

        self._force = force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRaidGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRaidGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRaidGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse200134RingBalance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'normal_percentage': 'int',
        'degraded_percentage': 'int',
        'critical_percentage': 'int',
        'normal_count': 'int',
        'degraded_count': 'int',
        'critical_count': 'int'
    }

    attribute_map = {
        'normal_percentage': 'normal_percentage',
        'degraded_percentage': 'degraded_percentage',
        'critical_percentage': 'critical_percentage',
        'normal_count': 'normal_count',
        'degraded_count': 'degraded_count',
        'critical_count': 'critical_count'
    }

    def __init__(self, normal_percentage=None, degraded_percentage=None, critical_percentage=None, normal_count=None, degraded_count=None, critical_count=None, _configuration=None):  # noqa: E501
        """InlineResponse200134RingBalance - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._normal_percentage = None
        self._degraded_percentage = None
        self._critical_percentage = None
        self._normal_count = None
        self._degraded_count = None
        self._critical_count = None
        self.discriminator = None

        if normal_percentage is not None:
            self.normal_percentage = normal_percentage
        if degraded_percentage is not None:
            self.degraded_percentage = degraded_percentage
        if critical_percentage is not None:
            self.critical_percentage = critical_percentage
        if normal_count is not None:
            self.normal_count = normal_count
        if degraded_count is not None:
            self.degraded_count = degraded_count
        if critical_count is not None:
            self.critical_count = critical_count

    @property
    def normal_percentage(self):
        """Gets the normal_percentage of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The normal_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._normal_percentage

    @normal_percentage.setter
    def normal_percentage(self, normal_percentage):
        """Sets the normal_percentage of this InlineResponse200134RingBalance.


        :param normal_percentage: The normal_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._normal_percentage = normal_percentage

    @property
    def degraded_percentage(self):
        """Gets the degraded_percentage of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The degraded_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._degraded_percentage

    @degraded_percentage.setter
    def degraded_percentage(self, degraded_percentage):
        """Sets the degraded_percentage of this InlineResponse200134RingBalance.


        :param degraded_percentage: The degraded_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._degraded_percentage = degraded_percentage

    @property
    def critical_percentage(self):
        """Gets the critical_percentage of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The critical_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._critical_percentage

    @critical_percentage.setter
    def critical_percentage(self, critical_percentage):
        """Sets the critical_percentage of this InlineResponse200134RingBalance.


        :param critical_percentage: The critical_percentage of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._critical_percentage = critical_percentage

    @property
    def normal_count(self):
        """Gets the normal_count of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The normal_count of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._normal_count

    @normal_count.setter
    def normal_count(self, normal_count):
        """Sets the normal_count of this InlineResponse200134RingBalance.


        :param normal_count: The normal_count of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._normal_count = normal_count

    @property
    def degraded_count(self):
        """Gets the degraded_count of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The degraded_count of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._degraded_count

    @degraded_count.setter
    def degraded_count(self, degraded_count):
        """Sets the degraded_count of this InlineResponse200134RingBalance.


        :param degraded_count: The degraded_count of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._degraded_count = degraded_count

    @property
    def critical_count(self):
        """Gets the critical_count of this InlineResponse200134RingBalance.  # noqa: E501


        :return: The critical_count of this InlineResponse200134RingBalance.  # noqa: E501
        :rtype: int
        """
        return self._critical_count

    @critical_count.setter
    def critical_count(self, critical_count):
        """Sets the critical_count of this InlineResponse200134RingBalance.


        :param critical_count: The critical_count of this InlineResponse200134RingBalance.  # noqa: E501
        :type: int
        """

        self._critical_count = critical_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200134RingBalance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200134RingBalance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200134RingBalance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.vpsa_object_storage_api import VPSAObjectStorageApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestVPSAObjectStorageApi(unittest.TestCase):
    """VPSAObjectStorageApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.vpsa_object_storage_api.VPSAObjectStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_drives_to_zios(self):
        """Test case for add_drives_to_zios

        """
        pass

    def test_add_proxy_virtual_controller_zios(self):
        """Test case for add_proxy_virtual_controller_zios

        """
        pass

    def test_add_virtual_nets_to_zios(self):
        """Test case for add_virtual_nets_to_zios

        """
        pass

    def test_add_zios_endpoints_configs_for_upload_types(self):
        """Test case for add_zios_endpoints_configs_for_upload_types

        """
        pass

    def test_assign_public_ip_zios(self):
        """Test case for assign_public_ip_zios

        """
        pass

    def test_change_engine_type_zios(self):
        """Test case for change_engine_type_zios

        """
        pass

    def test_continue_policy_rebalance_zios(self):
        """Test case for continue_policy_rebalance_zios

        """
        pass

    def test_create_storage_policy_zios(self):
        """Test case for create_storage_policy_zios

        """
        pass

    def test_create_zios_endpoints_configs_for_upload_types(self):
        """Test case for create_zios_endpoints_configs_for_upload_types

        """
        pass

    def test_create_zios_upload_endpoint(self):
        """Test case for create_zios_upload_endpoint

        """
        pass

    def test_create_zsnap_zios(self):
        """Test case for create_zsnap_zios

        """
        pass

    def test_delete_zios_endpoints_config_for_upload_types(self):
        """Test case for delete_zios_endpoints_config_for_upload_types

        """
        pass

    def test_delete_zios_upload_endpoint(self):
        """Test case for delete_zios_upload_endpoint

        """
        pass

    def test_disable_elastic_load_balancer_zios(self):
        """Test case for disable_elastic_load_balancer_zios

        """
        pass

    def test_enable_elastic_load_balancer_zios(self):
        """Test case for enable_elastic_load_balancer_zios

        """
        pass

    def test_get_all_vpsaos(self):
        """Test case for get_all_vpsaos

        """
        pass

    def test_get_all_zios_drives_from_cc(self):
        """Test case for get_all_zios_drives_from_cc

        """
        pass

    def test_get_load_balancer(self):
        """Test case for get_load_balancer

        """
        pass

    def test_get_vpsaos_accounts(self):
        """Test case for get_vpsaos_accounts

        """
        pass

    def test_get_vpsaos_comments(self):
        """Test case for get_vpsaos_comments

        """
        pass

    def test_get_vpsaos_sps(self):
        """Test case for get_vpsaos_sps

        """
        pass

    def test_get_vpsaos_vcs(self):
        """Test case for get_vpsaos_vcs

        """
        pass

    def test_get_zios_from_cloud(self):
        """Test case for get_zios_from_cloud

        """
        pass

    def test_get_zios_upload_endpoints(self):
        """Test case for get_zios_upload_endpoints

        """
        pass

    def test_hibernate_zios(self):
        """Test case for hibernate_zios

        """
        pass

    def test_list_availiables_virtual_net_to_add_vpsa(self):
        """Test case for list_availiables_virtual_net_to_add_vpsa

        """
        pass

    def test_list_vpsa_virtual_nets(self):
        """Test case for list_vpsa_virtual_nets

        """
        pass

    def test_list_zios_endpoints_configs_by_upload_types(self):
        """Test case for list_zios_endpoints_configs_by_upload_types

        """
        pass

    def test_maintenance_mode(self):
        """Test case for maintenance_mode

        """
        pass

    def test_pause_policy_rebalance_zios(self):
        """Test case for pause_policy_rebalance_zios

        """
        pass

    def test_remove_virtual_nets_from_zios(self):
        """Test case for remove_virtual_nets_from_zios

        """
        pass

    def test_restore_zios(self):
        """Test case for restore_zios

        """
        pass

    def test_unassign_public_ip_zios(self):
        """Test case for unassign_public_ip_zios

        """
        pass

    def test_update_zios_upload_endpoint(self):
        """Test case for update_zios_upload_endpoint

        """
        pass

    def test_upgrade_zios(self):
        """Test case for upgrade_zios

        """
        pass


if __name__ == '__main__':
    unittest.main()
